"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var tezt_1 = require("tezt");
var validatorz_1 = require("./validatorz");
var index_1 = require("./index");
var expect_1 = __importDefault(require("expect"));
var vehicles = ['Motorcycle', 'Bus', 'Car'];
var testValidator = function (fn, val, expectedVal, debug) {
    expect_1.default(fn(val)).toEqual(expectedVal);
};
tezt_1.test('create binary hash', function () {
    var mustContain = ["letters", "digits", "uppercase"];
    var binaryHash = mustContain
        .reverse()
        .map(validatorz_1.getHash)
        .reduce(validatorz_1.createBinaryHash, {});
    expect_1.default(binaryHash["Z"]).toBe(5);
    expect_1.default(binaryHash["1"]).toBe(2);
    expect_1.default(binaryHash["z"]).toBe(4);
    var checkVal = parseInt("1".repeat(mustContain.length), 2);
    expect_1.default(binaryHash["Z"] | binaryHash["1"]).toBe(checkVal);
});
tezt_1.test('it detects valid chars', function () {
    var lowercaseValidator = validatorz_1.createValidCharsValidator("lowercase");
    var uppercaseValidator = validatorz_1.createValidCharsValidator("uppercase");
    testValidator(lowercaseValidator, "ubqoeribuqnerf", []);
    testValidator(lowercaseValidator, "ubqoeRIBUQNErf", [new Error("R is not allowed. Only \"lowercase\" are allowed.")]);
    testValidator(uppercaseValidator, "ASDLFJALEKJFQWEK", []);
    testValidator(uppercaseValidator, "ubqoeRIBUQNErf", [new Error("u is not allowed. Only \"uppercase\" are allowed.")]);
});
tezt_1.test('it detects must contain', function () {
    var mustContain = ["letters", "symbols", "#! "];
    var mustContainValidator = validatorz_1.createMustContainValidator(mustContain);
    testValidator(mustContainValidator, "a!we #", []);
    testValidator(mustContainValidator, "aweasdqweq$", [new Error("Must contain \"#! \"")], true);
});
tezt_1.test('integration all checkers', function () {
    var passwordValidator = validatorz_1.createStringValidator({
        mustContain: ["symbols", "uppercase", "lowercase", "digits"],
        validChars: ["symbols", "alphanumeric"],
        min: 8,
        max: 45,
    });
    testValidator(passwordValidator, "Password#1805", []);
    testValidator(passwordValidator, "passd05", [
        new Error("Must contain \"uppercase\" and \"symbols\""),
        new Error("Must be at least 8 characters long."),
    ]);
});
tezt_1.test('use presets', function () {
    testValidator(index_1.validateEmail, "zwhit_chcox@gmail.com", []);
    testValidator(index_1.validateEmail, "password#1805", [new Error('Invalid input.')]);
});
tezt_1.test('digits', function () {
    var numberValidator = validatorz_1.createNumberValidator({
        min: 3,
        max: 9,
    });
    testValidator(numberValidator, 3, []);
    testValidator(numberValidator, 1, [new Error("Must be greater than or equal to 3.")]);
    testValidator(numberValidator, 10, [new Error("Must be less than or equal to 9.")]);
});
tezt_1.test('validateDOB', function () {
    testValidator(index_1.validateDOB, new Date(1920, 1, 1), []);
    testValidator(index_1.validateDOB, new Date(1820, 1, 1), [new Error("Date of birth cannot be before January 1, 1900")]);
});
tezt_1.test("oneOf validator", function () {
    var fruitValidator = validatorz_1.createOneOfValidator({ options: ["apples", "oranges", "bananas"] });
    expect_1.default(fruitValidator("peanuts")).toEqual([new Error("Must be apples, oranges, or bananas.")]);
    expect_1.default(fruitValidator("oranges")).toEqual([]);
});
//# sourceMappingURL=validatorz.test.js.map